All of lore.kernel.org
 help / color / mirror / Atom feed
From: Chandan Babu R <chandan.babu@oracle.com>
To: linux-xfs@vger.kernel.org
Cc: Chandan Babu R <chandan.babu@oracle.com>,
	djwong@kernel.org, cem@kernel.org
Subject: [PATCH V2 20/23] mdrestore: Introduce mdrestore v1 operations
Date: Tue,  6 Jun 2023 14:58:03 +0530	[thread overview]
Message-ID: <20230606092806.1604491-21-chandan.babu@oracle.com> (raw)
In-Reply-To: <20230606092806.1604491-1-chandan.babu@oracle.com>

In order to indicate the version of metadump files that they can work with,
this commit renames read_header(), show_info() and restore() functions to
read_header_v1(), show_info_v1() and restore_v1() respectively.

Signed-off-by: Chandan Babu R <chandan.babu@oracle.com>
---
 mdrestore/xfs_mdrestore.c | 39 ++++++++++++++++++---------------------
 1 file changed, 18 insertions(+), 21 deletions(-)

diff --git a/mdrestore/xfs_mdrestore.c b/mdrestore/xfs_mdrestore.c
index 5451a58b..b34eda2c 100644
--- a/mdrestore/xfs_mdrestore.c
+++ b/mdrestore/xfs_mdrestore.c
@@ -86,7 +86,7 @@ open_device(
 }
 
 static void
-read_header(
+read_header_v1(
 	void			*header,
 	FILE			*md_fp)
 {
@@ -100,7 +100,7 @@ read_header(
 }
 
 static void
-show_info(
+show_info_v1(
 	void			*header,
 	const char		*md_file)
 {
@@ -117,24 +117,14 @@ show_info(
 	}
 }
 
-/*
- * restore() -- do the actual work to restore the metadump
- *
- * @src_f: A FILE pointer to the source metadump
- * @dst_fd: the file descriptor for the target file
- * @is_target_file: designates whether the target is a regular file
- * @mbp: pointer to metadump's first xfs_metablock, read and verified by the caller
- *
- * src_f should be positioned just past a read the previously validated metablock
- */
 static void
-restore(
+restore_v1(
 	void			*header,
 	FILE			*md_fp,
 	int			ddev_fd,
-	int			is_target_file)
+	bool			is_target_file)
 {
-	struct xfs_metablock	*metablock;	/* header + index + blocks */
+	struct xfs_metablock	*metablock;
 	struct xfs_metablock	*mbp;
 	__be64			*block_index;
 	char			*block_buffer;
@@ -259,6 +249,12 @@ restore(
 	free(metablock);
 }
 
+static struct mdrestore_ops mdrestore_ops_v1 = {
+	.read_header	= read_header_v1,
+	.show_info	= show_info_v1,
+	.restore	= restore_v1,
+};
+
 static void
 usage(void)
 {
@@ -310,9 +306,9 @@ main(
 
 	/*
 	 * open source and test if this really is a dump. The first metadump
 	 * block will be passed to restore() which will continue to read the
 	 * file from this point. This avoids rewind the stream, which causes
 	 * restore to fail when source was being read from stdin.
  	 */
 	if (strcmp(argv[optind], "-") == 0) {
 		src_f = stdin;
@@ -330,16 +326,17 @@ main(
 	switch (be32_to_cpu(magic)) {
 	case XFS_MD_MAGIC_V1:
 		header = &mb;
+		mdrestore.mdrops = &mdrestore_ops_v1;
 		break;
 	default:
 		fatal("specified file is not a metadata dump\n");
 		break;
 	}
 
-	read_header(header, src_f);
+	mdrestore.mdrops->read_header(header, src_f);
 
 	if (mdrestore.show_info) {
-		show_info(header, argv[optind]);
+		mdrestore.mdrops->show_info(header, argv[optind]);
 
 		if (argc - optind == 1)
 			exit(0);
@@ -350,7 +347,7 @@ main(
 	/* check and open target */
 	dst_fd = open_device(argv[optind], &is_target_file);
 
-	restore(header, src_f, dst_fd, is_target_file);
+	mdrestore.mdrops->restore(header, src_f, dst_fd, is_target_file);
 
 	close(dst_fd);
 	if (src_f != stdin)
@@ -310,9 +306,9 @@ main(
 	/*
 	 * open source and test if this really is a dump. The first metadump
-	 * block will be passed to restore() which will continue to read the
-	 * file from this point. This avoids rewind the stream, which causes
-	 * restore to fail when source was being read from stdin.
+	 * block will be passed to mdrestore_ops->restore() which will continue
+	 * to read the file from this point. This avoids rewind the stream,
+	 * which causes restore to fail when source was being read from stdin.
  	 */
 	if (strcmp(argv[optind], "-") == 0) {
-- 
2.39.1


  parent reply	other threads:[~2023-06-06  9:30 UTC|newest]

Thread overview: 54+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
     [not found] <2ExBvYxYPnyiGvOJzODNvNXx_bfn5RWAck_7UcV7OvxkF6fgAy6UZtI6d2-FdmxoIeBLPPX0vwW9uaJxBa5Rmg==@protonmail.internalid>
2023-06-06  9:27 ` [PATCH V2 00/23] Metadump v2 Chandan Babu R
2023-06-06  9:27   ` [PATCH V2 01/23] metadump: Use boolean values true/false instead of 1/0 Chandan Babu R
2023-06-06  9:27   ` [PATCH V2 02/23] mdrestore: Fix logic used to check if target device is large enough Chandan Babu R
2023-06-06  9:27   ` [PATCH V2 03/23] metadump: Declare boolean variables with bool type Chandan Babu R
2023-06-06 15:17     ` Darrick J. Wong
2023-06-06  9:27   ` [PATCH V2 04/23] metadump: Define and use struct metadump Chandan Babu R
2023-07-12 18:12     ` Darrick J. Wong
2023-07-20 13:13       ` Carlos Maiolino
2023-07-20 17:22         ` Darrick J. Wong
2023-06-06  9:27   ` [PATCH V2 05/23] metadump: Add initialization and release functions Chandan Babu R
2023-06-06  9:27   ` [PATCH V2 06/23] metadump: Postpone invocation of init_metadump() Chandan Babu R
2023-07-12 17:00     ` Darrick J. Wong
2023-06-06  9:27   ` [PATCH V2 07/23] metadump: Introduce struct metadump_ops Chandan Babu R
2023-07-12 17:06     ` Darrick J. Wong
2023-06-06  9:27   ` [PATCH V2 08/23] metadump: Introduce metadump v1 operations Chandan Babu R
2023-07-12 17:10     ` Darrick J. Wong
2023-07-13  4:36       ` Chandan Babu R
2023-06-06  9:27   ` [PATCH V2 09/23] metadump: Rename XFS_MD_MAGIC to XFS_MD_MAGIC_V1 Chandan Babu R
2023-06-06  9:27   ` [PATCH V2 10/23] metadump: Define metadump v2 ondisk format structures and macros Chandan Babu R
2023-07-12 17:18     ` Darrick J. Wong
2023-07-13  4:37       ` Chandan Babu R
2023-06-06  9:27   ` [PATCH V2 11/23] metadump: Define metadump ops for v2 format Chandan Babu R
2023-07-12 17:22     ` Darrick J. Wong
2023-07-13  4:45       ` Chandan Babu R
2023-06-06  9:27   ` [PATCH V2 12/23] xfs_db: Add support to read from external log device Chandan Babu R
2023-07-12 17:35     ` Darrick J. Wong
2023-07-13  5:24       ` Chandan Babu R
2023-06-06  9:27   ` [PATCH V2 13/23] metadump: Add support for passing version option Chandan Babu R
2023-06-06  9:27   ` [PATCH V2 14/23] mdrestore: Declare boolean variables with bool type Chandan Babu R
2023-07-12 17:35     ` Darrick J. Wong
2023-06-06  9:27   ` [PATCH V2 15/23] mdrestore: Define and use struct mdrestore Chandan Babu R
2023-07-12 18:12     ` Darrick J. Wong
2023-06-06  9:27   ` [PATCH V2 16/23] mdrestore: Detect metadump v1 magic before reading the header Chandan Babu R
2023-07-12 17:38     ` Darrick J. Wong
2023-06-06  9:28   ` [PATCH V2 17/23] mdrestore: Add open_device(), read_header() and show_info() functions Chandan Babu R
2023-07-12 17:46     ` Darrick J. Wong
2023-07-13  5:27       ` Chandan Babu R
2023-06-06  9:28   ` [PATCH V2 18/23] mdrestore: Introduce struct mdrestore_ops Chandan Babu R
2023-06-06  9:28   ` [PATCH V2 19/23] mdrestore: Replace metadump header pointer argument with generic pointer type Chandan Babu R
2023-07-12 17:55     ` Darrick J. Wong
2023-07-13  6:08       ` Chandan Babu R
2023-06-06  9:28   ` Chandan Babu R [this message]
2023-07-12 17:57     ` [PATCH V2 20/23] mdrestore: Introduce mdrestore v1 operations Darrick J. Wong
2023-06-06  9:28   ` [PATCH V2 21/23] mdrestore: Extract target device size verification into a function Chandan Babu R
2023-06-06  9:28   ` [PATCH V2 22/23] mdrestore: Define mdrestore ops for v2 format Chandan Babu R
2023-07-12 18:10     ` Darrick J. Wong
2023-07-13  6:27       ` Chandan Babu R
2023-07-13 14:22         ` Darrick J. Wong
2023-06-06  9:28   ` [PATCH V2 23/23] mdrestore: Add support for passing log device as an argument Chandan Babu R
2023-07-12 18:10     ` Darrick J. Wong
     [not found]       ` <181e7cbefa39e2dc59f2564c25966ac0d05aa6530483b7eb5d649de9a3d1cf7f@mu.id>
2023-07-13  6:48         ` Chandan Babu R
2023-06-06 12:10   ` [PATCH V2 00/23] Metadump v2 Carlos Maiolino
2023-06-06 12:38     ` Chandan Babu R
2023-06-06 16:04       ` Carlos Maiolino

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20230606092806.1604491-21-chandan.babu@oracle.com \
    --to=chandan.babu@oracle.com \
    --cc=cem@kernel.org \
    --cc=djwong@kernel.org \
    --cc=linux-xfs@vger.kernel.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.